
-- return the window size
function getWindowSize()
	return 600, 500
end

-- return the main font
-- the return is a list of font filename and size options
-- the first one found will be used
function getFont()
	if isMac then
		return { { name="GillSans.ttc", size=14 }, { name="GillSans.dfont", size=14 }, { name="Monaco.dfont", size=12 } }
	else
		return { { name="tahoma.ttf", size=14 }, { name="arial.ttf", size=12 } }
	end
end
-- return the label font
function getLabelFont()
	if isMac then
		return { { name="GillSans.ttc", size=11 }, { name="GillSans.dfont", size=11 }, { name="Monaco.dfont", size=9 } }
	else
		return { { name="tahoma.ttf", size=11 }, { name="arial.ttf", size=9 } }
	end
end
-- return the text field font
function getTextFieldFont()
	if isMac then
		return { { name="GillSans.ttc", size=12 }, { name="GillSans.dfont", size=12 }, { name="Monaco.dfont", size=10 } }
	else
		return { { name="tahoma.ttf", size=12 }, { name="arial.ttf", size=10 } }
	end
end

-- create and lay out all the controls
function createUI()

	-- load textures
	atlas = texture( "buttons.png" )
	background = texture( "background.png" )
	setBackgroundTexture( background )

	local windowW, windowH = getWindowSize()
	
	-- set location of the banner
	setBannerPosition( 10.0, false )
	
	-- set outline colours for groups
	setGroupActiveColour( 0.95, 0.9, 0.9, 1.0 )
	setGroupInactiveColour( 0.8, 0.4, 0.01, 1.0 )
	
	-- constants
	local kTextFieldH = 12
	local kKnobSize = 42
	local kKnobSpace = 54
	local kButtonW = 48
	local kButtonH = 12
	local kButtonSpaceH = 52
	local kButtonU = 49
	local kButtonV = 2*kButtonH+1
		
	-- make renderers
	theKnobRenderer = knobRenderer( atlas, 5*kButtonU, 0, kKnobSize )
	theButtonRenderer = buttonRenderer( atlas )

	-- controls
	
	local x = windowW - 10 - kButtonW - 60
	local y = 10

	add( button( "Prefs", "Prefs", x, y, kButtonW, kButtonH, 4*kButtonU, 0 ) )

	theWaveformDisplayMovingButton = luaButton( toggleWaveformMoving, "Moving", "Toggle moving waveform", "toggle", x + 60, y, kButtonW, kButtonH, 4*kButtonU, kButtonV )
	add( theWaveformDisplayMovingButton )
	
	x = 10
	y = y + 20

	theWaveformDisplay = waveformDisplay( x, y, windowW - 2*10, windowH - y - 10 )
	add( theWaveformDisplay )
	theWaveformDisplay:setMoving( true )

end		-- of createUI()

function toggleWaveformMoving()
	theWaveformDisplay:setMoving( not theWaveformDisplay:isMoving() )
end
